;=============================================================================
; Insight, real-mode debugger for MS DOS / PC DOS / FreeDOS.
; Copyright (c) Victor M. Gamayunov, Sergey Pimenov, 1993, 96, 97, 2002.
; Modifications by Oleg O. Chukaev (2006 - 2009).
;-----------------------------------------------------------------------------
; config.inc
; Configuration dialog.
;-----------------------------------------------------------------------------
; This program is free software; you can redistribute it and/or
; modify it under the terms of the GNU General Public License
; as published by the Free Software Foundation; either version 2
; of the License, or (at your option) any later version.
;
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
;
; You should have received a copy of the GNU General Public License
; along with this program; if not, write to the Free Software
; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
; 02110-1301 USA
;=============================================================================

open_config:
	mov byte [config_dlg_item], 0

	mov ax, word [cursor_large]
	mov di, cursor_large_string
	call fill_word_str
	mov al, 0
	stosb

	mov ax, word [cursor_small]
	mov di, cursor_small_string
	call fill_word_str
	mov al, 0
	stosb

.loop:
	mov si, config_dialog
	call init_dialog
	call exec_dialog_
	cmp ax, CM_CANCEL
	je .nocursor
	cmp ax, 3
	je .redraw

	mov di, sp

	mov si, cursor_large_string
	call get_hex_value
	jc .invalid
	cmp byte [si], 0
	jne .invalid
	push bx

	mov si, cursor_small_string
	call get_hex_value
	jc .invalid
	cmp byte [si], 0
	jne .invalid
	mov word [cursor_small], bx
	pop word [cursor_large]

.nocursor:
	call initialise_draw_table
	call draw_screen
	retn

.invalid:
	mov sp, di
	mov si, cursor_error_msg
	call _error_message
	jmp .loop

.redraw:
	call initialise_draw_table
	call draw_screen
	jmp .loop

redraw_config_change:
	mov ax, 3
	stc
	retn


open_terminal_settings:
	mov byte [terminalsettings_dlg_item], 0

	mov ax, word [portnumber]
	mov di, portnumber_string
	call fill_word_str
	mov al, 0
	stosb

	mov ax, word [intnumber]
	mov di, intnumber_string
	call fill_byte_str
	mov al, 0
	stosb

	mov ax, word [irqmask]
	mov di, irqmask_string
	call fill_word_str
	mov al, 0
	stosb

.loop:
		mov	ax, 7
		call	init_string_list

	mov si, baudstrings
@@next:
		mov	al,' '
		mov	cx, 6
		mov	di,string
	rep	stosb
		mov	byte [es:di],0

	mov di, string
	call strlen
	rep movsb
	inc si

	push si
		mov	si,string
		call	add_string	;Add string to list
	pop si
	cmp si, baudstrings.end
	jb @@next

@@:
	mov ax, [baudlistchoice]
	jmp @F

.reinit:
	mov ax, [list_choice]
	cmp ax, -1
	je @B
	mov word [baudlistchoice], ax
@@:
	mov word [active_list_choice], ax

	mov si, terminalsettings_dialog
	call init_dialog
	call exec_dialog_
	cmp ax, CM_CANCEL
	je .noserial
	cmp ax, 3
	je .redraw
	cmp ax, 4
	je .reinit

	mov ax, [list_choice]
	cmp ax, -1
	je @F
	mov word [baudlistchoice], ax
	cmp word [linespeed], ax
	je @F
	mov word [linespeed], ax
	rol byte [terminal_connected], 1
	jnc @F
	call SPEEDSET
@@:

	mov di, sp

	mov si, portnumber_string
	call get_hex_value
	jc .invalid
	cmp byte [si], 0
	jne .invalid
	push bx

	mov si, intnumber_string
	call get_hex_value
	jc .invalid
	cmp byte [si], 0
	jne .invalid
	push bx

	mov si, irqmask_string
	call get_hex_value
	jc .invalid
	cmp byte [si], 0
	jne .invalid
	mov word [irqmask], bx
	pop word [intnumber]
	pop word [portnumber]

.noserial:
	call initialise_draw_table
	call draw_screen
	retn

.invalid:
	mov sp, di
	mov si, serialnumber_error_msg
	call _error_message
	jmp .loop

.redraw:
	call initialise_draw_table
	call draw_screen
	jmp .loop

enable_serial_manual:
	and byte [config_serial_item1], ~ DISABLED
	and byte [config_serial_item2], ~ DISABLED
	and byte [config_serial_item3], ~ DISABLED
	jmp @F

disable_serial_manual:
	or byte [config_serial_item1], DISABLED
	or byte [config_serial_item2], DISABLED
	or byte [config_serial_item3], DISABLED
@@:
	mov ax, 4
	stc
	retn
